<?php
/**
 * @file
 * Contains Drupal\djovernetzung\Plugin\Filter\FilterCelebrate
 */

namespace Drupal\djovernetzung\Plugin\Filter;

use Drupal\filter\FilterProcessResult;
use Drupal\filter\Plugin\FilterBase;
use Drupal\Core\Form\FormStateInterface;

define('DJO_VERSION', '9.1');
define('SITE_NAME', \Drupal::config('system.site')->get('name'));
/**
 * Stellt die dejure.org Vernetzung bereit.
 *
 * @Filter(
 *   id = "filter_djovernetzung",
 *   title = @Translation("dejure.org Vernetzungsfunktion"),
 *   description = @Translation("Wandelt rechtliche Angaben in Texten (Aktenzeichen, Paragraphen) in Links zu dejure.org um. Sendet Texte zur Durchfuehrung an dejure.org."),
 *   type = Drupal\filter\Plugin\FilterInterface::TYPE_MARKUP_LANGUAGE,
 * )
 */
class djoVernetzung extends FilterBase {

	/**
	 * {@inheritdoc}
	 */
	public function process($text, $langcode) {

		$text = $this->vernetzen_ueber_dejure_org($text);
		return new FilterProcessResult($text);

	}

	/**
	 * Text an dejure.org senden und, falls Verarbeitung erfolgreich, zurueckgeben.
	 */
	public function vernetzen_ueber_dejure_org($text, $form = array()) {
		if (!preg_match('/§|&sect;|&#167;|Artt?\.|[\/\.] ?[0-9][0-9](?![0-9\/])| [0-9][0-9]?[\/\.] ?[0-9][0-9](?![0-9\.])| [A-Z]+ [0-9][0-9]\. ?[0-9]|[0-9][0-9],/', $text)) {
			return $text;
		}

		//$config = $this->config('djovernetzung.settings');
		$config = \Drupal::config('djovernetzung.settings');

		$arr_data = array(
			'Originaltext'		=> $text,
			'Anbieterkennung'	=> ($config->get('anbieterkennung') ? $config->get('anbieterkennung') : SITE_NAME).($config->get('email') ? '__'.$config->get('email') : ''),
			'version'			=> 'drupal-'.DJO_VERSION,
			'format'			=> $config->get('linkformat') ? $config->get('linkformat') : 'weit',
			'class'				=> $config->get('class') ? $config->get('class') : '',
			'target'			=> $config->get('target') ? $config->get('target') : '',
			'Schema'			=> 'https',
			'buzer'				=> $config->get('buzer') ? $config->get('buzer') : 0,
		);

		$result = \Drupal::httpClient()->post('http://rechtsnetz.dejure.org/dienste/vernetzung/vernetzen', [
			'form_params'	=> $arr_data,
			'headers'		=> array('Content-Type' => 'application/x-www-form-urlencoded', 'User-Agent' => $_SERVER['SERVER_NAME'].' (Drupal-Vernetzung '.DJO_VERSION.')'),
			'timeout'		=> 2,
		]);

		// Rueckgabe der Vernetzung in Ordnung?
		// Falls nicht, Original zurureckgaben.
		if (!empty($result) && $result->getStatusCode() == '200') {
			return $this->integritaetskontrolle($text, $result->getBody()->getContents());
		} else {
			return $text;
		}
	}

	/**
	 * Vernetzten Text auf Vollstaendigkeit pruefen.
	 * Vergleicht Originaltext mit dem Vernetzten. Bei Unterschieden das Original zurueckgeben.
	 */
	public function integritaetskontrolle($ausgangstext, $neuertext) {
		if (preg_replace("/<a href=\"https?:\/\/dejure.org\/[^>]*>([^<]*)<\/a>/i", "\\1", trim($ausgangstext)) == preg_replace("/<a href=\"https?:\/\/dejure.org\/[^>]*>([^<]*)<\/a>/i", "\\1", trim($neuertext))) {
			return $neuertext;
		} else {
			return $ausgangstext;
		}
	}
}
